@@ -21,6 +21,8 @@ if sys.maxsize > 2**32:
 else:
     r_version_folder = 'i386'
 
+ENVVAR_CFFI_TYPE: str = 'RPY2_CFFI_MODE'
+
 
 class CFFI_MODE(enum.Enum):
     API = 'API'
@@ -30,7 +32,7 @@ class CFFI_MODE(enum.Enum):
 
 
 def get_cffi_mode(default=CFFI_MODE.ANY):
-    cffi_mode = os.environ.get('RPY2_CFFI_MODE', '')
+    cffi_mode = os.environ.get(ENVVAR_CFFI_TYPE, '')
     res = default
     for m in (CFFI_MODE.API, CFFI_MODE.ABI,
               CFFI_MODE.BOTH, CFFI_MODE.ANY):
@@ -157,20 +159,11 @@ def r_ld_library_path_from_subprocess(r_home: str) -> str:
                                              universal_newlines=True,
                                              stderr=subprocess.PIPE)
         logger.info(f'R library path: {r_lib_path}')
-    except Exception as e:  # FileNotFoundError, WindowsError, etc
+    except Exception as e:  # FileNotFoundError, WindowsError, etc.
         logger.error(f'Unable to determine R library path: {e}')
         r_lib_path = ''
-    res = None
-    ld_library_path = os.environ.get('LD_LIBRARY_PATH')
-    if ld_library_path:
-        pos = r_lib_path.find(ld_library_path)
-        if pos != -1:
-            res = (r_lib_path[pos:(pos+len(ld_library_path))]
-                   .rstrip(os.pathsep))
-    if res is None:
-        res = r_lib_path
-    logger.info(f'LD_LIBRARY_PATH: {res}')
-    return res
+    logger.info(f'LD_LIBRARY_PATH: {r_lib_path}')
+    return r_lib_path
 
 
 def get_rlib_rpath(r_home: str) -> str:
@@ -409,7 +402,7 @@ def iter_info():
 
     # not applicable for Windows
     if os.name != 'nt':
-        yield make_bold("R's additions to LD_LIBRARY_PATH:")
+        yield make_bold("R's value for LD_LIBRARY_PATH:")
         if r_home is None:
             yield '     *** undefined when not R home can be determined'
         else:
@@ -460,6 +453,15 @@ def iter_info():
     yield 'Directory for the R shared library:'
     yield get_r_libnn(r_home)
 
+    yield make_bold('CFFI extension type')
+    yield f'  Environment variable: {ENVVAR_CFFI_TYPE}'
+    yield f'  Value: {get_cffi_mode()}'
+
+    import importlib
+    for cffi_type in ('abi', 'api'):
+        rinterface_cffi_spec = importlib.util.find_spec(f'_rinterface_cffi_{cffi_type}')
+        yield f'  {cffi_type.upper()}: {"PRESENT" if rinterface_cffi_spec else "ABSENT"}'
+
 
 def set_default_logging():
     logformatter = logging.Formatter('%(name)s: %(message)s')
